Struct SctkLayerSurfaceSettings
pub struct SctkLayerSurfaceSettings {
pub id: Id,
pub layer: Layer,
pub keyboard_interactivity: KeyboardInteractivity,
pub input_zone: Option<Vec<Rectangle>>,
pub anchor: Anchor,
pub output: IcedOutput,
pub namespace: String,
pub margin: IcedMargin,
pub size: Option<(Option<u32>, Option<u32>)>,
pub exclusive_zone: i32,
pub size_limits: Limits,
}Expand description
layer surface
Fields
id: IdXXX id must be unique for every surface, window, and popup
layer: Layerlayer
keyboard_interactivity: KeyboardInteractivitykeyboard interactivity
input_zone: Option<Vec<Rectangle>>input zone None results in accepting all input
anchor: Anchoranchor, if a surface is anchored to two opposite edges, it will be stretched to fit between those edges, regardless of the specified size in that dimension.
output: IcedOutputoutput
namespace: Stringnamespace
margin: IcedMarginmargin
size: Option<(Option<u32>, Option<u32>)>XXX size, providing None will autosize the layer surface to its contents If Some size is provided, None in a given dimension lets the compositor decide for that dimension, usually this would be done with a layer surface that is anchored to left & right or top & bottom
exclusive_zone: i32exclusive zone
size_limits: LimitsLimits of the popup size